// Copyright 2022 Alibaba Group Holding Limited.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
#ifndef _Included_java_lang_Class
#define _Included_java_lang_Class

jstring JavaClass_getName(JNIEnv*, jobject);
jobjectArray JavaClass_getConstructors(JNIEnv*, jobject);
jobjectArray JavaClass_getMethods(JNIEnv*, jobject);
jobjectArray JavaClass_getFields(JNIEnv*, jobject);
jclass JavaClass_getComponentType(JNIEnv*, jobject);
jboolean JavaClass_isArray(JNIEnv*, jobject);

#endif
